def 模块_更新内容查看():
    更新内容 = """
    1.0.173：2024年7月12日
    新增命令：模块_更新内容查看
    --------------------------------
    1.0.172：2024年7月12日
    新增命令：mysql_克隆表单_仅结构
    新增命令：mysql_克隆表单_结构和数据
    新增命令：mysql_更新_字段名
    新增命令：mysql_查询_表结构
    新增命令：mysql_创建新表
    """
    print(更新内容)